@@ -1,8 +1,9 @@
-#!/usr/bin/env python
+__all__ = ['sanitize', 'jsfiddle_url']
+
+
 import github_gist
 import github_name
 import os
-import public
 import re
 
 """
@@ -20,7 +21,7 @@ def sanitize(path, replacement="_"):
     """return a sanitized path supported by jsfiddle.net"""
     if replacement is None:
         replacement = "_"
-    return re.sub("[^!@#$&*()'?\\/_0-9a-zA-Z]+", replacement, path)
+    return re.sub('[^!@#$&*()\'?\\/_\-0-9a-zA-Z]+', replacement, path)
 
 
 def git_root():
@@ -40,13 +41,12 @@ def github_tree():
     return "/".join([fullname, "tree/master", relpath])
 
 
-@public.add
 def jsfiddle_url():
     """return jsfiddle url for a current directory. git remote required"""
     _github_tree = github_tree()
     if not _github_tree:
         return ""
-    gist_id=github_gist.getid()
+    gist_id = github_gist.getid()
     if gist_id:
         return "http://jsfiddle.net/gh/gist/library/pure/%s/" % gist_id
     return "https://jsfiddle.net/gh/get/library/pure/%s/" % github_tree()
